@@ -13,7 +13,8 @@ import sys
 import argparse
 
 from .cons3rtconfig import manual_config
-from .cons3rtcli import CloudCli, CloudspaceCli, DeploymentCli, ProjectCli, RunCli, ScenarioCli, SystemCli, TeamCli
+from .cons3rtcli import CloudCli, CloudspaceCli, DeploymentCli, ProjectCli, RunCli, ScenarioCli, SystemCli, TeamCli, \
+    UserCli
 
 # Commands for setting up the cons3rtapi configuration
 setup_command_options = [
@@ -31,7 +32,8 @@ valid_commands = setup_command_options + [
     'system',
     'scenario',
     'run',
-    'team'
+    'team',
+    'user'
 ]
 
 # String representation of valid commands
@@ -94,20 +96,35 @@ def team_cli(args, subcommands):
     return 1
 
 
+def user_cli(args, subcommands):
+    c = UserCli(args, subcommands)
+    if c.process_args():
+        return 0
+    return 1
+
+
 def main():
     parser = argparse.ArgumentParser(description='CONS3RT command line interface (CLI)')
     parser.add_argument('command', help='Command for the cons3rt CLI')
     parser.add_argument('subcommands', help='Optional command subtype', nargs='*')
     parser.add_argument('--active', help='Process only active items', required=False, action='store_true')
+    parser.add_argument('--after', help='After a specified date, format: YYYY-MM-DD', required=False)
     parser.add_argument('--all', help='All action relative to the command provided', action='store_true')
     parser.add_argument('--assets', help='Specify to run the asset reports', action='store_true')
+    parser.add_argument('--before', help='Before a specified date, format: YYYY-MM-DD', required=False)
+    parser.add_argument('--blocked', help='Include blocked users', required=False, action='store_true')
     parser.add_argument('--clean_all_runs', help='Clean all runs from a cloudspace', action='store_true')
     parser.add_argument('--cloud_ato_consent', help='Consent to the cloud ATO', action='store_true')
     parser.add_argument('--cloud_type', help='Type of cloud virtualization technology (awsCloud, azureCloud, '
                                              'openStackCloud, vCloudCloud, vCloudRestCloud)', required=False)
+    parser.add_argument('--cloudspaces', help='Print cloudspaces for a cloud', required=False, action='store_true')
     parser.add_argument('--config', help='Path to a config file to load', required=False)
+    parser.add_argument('--cpu', help='CPU count info relevant to the CLI call', required=False)
+    parser.add_argument('--csv', help='Use csv format for the output', required=False, action='store_true')
     parser.add_argument('--delete', help='Delete action relative to the command provided', action='store_true')
     parser.add_argument('--delete_inactive_runs', help='Delete inactive runs from a cloudspace', action='store_true')
+    parser.add_argument('--emails', help='Get a semi-colon separated list of email addresses for the output',
+                        required=False, action='store_true')
     parser.add_argument('--expired', help='Process only expired items', required=False, action='store_true')
     parser.add_argument('--id', help='ID relative to the command provided', required=False)
     parser.add_argument('--ids', help='List of IDs relative to the command provided', required=False)
@@ -117,7 +134,7 @@ def main():
     parser.add_argument('--linux_repo_url', help='URL of the Cloud Linux Repo', required=False)
     parser.add_argument('--list', help='List action for the provided command', action='store_true')
     parser.add_argument('--list_active_runs', help='List active runs in a cloudspace', action='store_true')
-    parser.add_argument('--load', help='Load local data vs. query for reports', action='store_true')
+    parser.add_argument('--load', help='Load local data when available', action='store_true')
     parser.add_argument('--my', help='Modifier for list action for only my things', action='store_true')
     parser.add_argument('--name', help='Name of a resource', required=False)
     parser.add_argument('--names', help='List of names of resources', required=False)
@@ -129,8 +146,11 @@ def main():
     parser.add_argument('--run', help='Run ID relative to the command provided', required=False)
     parser.add_argument('--runs', help='Run ID(s) relative to the command provided', required=False)
     parser.add_argument('--share', help='Share templates', action='store_true')
-    parser.add_argument('--state', help='Project membership state')
+    parser.add_argument('--skip', help='List of items to skip', required=False)
+    parser.add_argument('--state', help='Project membership state, user state', required=False)
+    parser.add_argument('--tool', help='Name of a collab tool service', required=False)
     parser.add_argument('--unexpired', help='Process only unexpired items', required=False, action='store_true')
+    parser.add_argument('--unique', help='Return unique items', required=False, action='store_true')
     parser.add_argument('--unlock', help='Remove run locks before taking action', action='store_true')
     parser.add_argument('--username', help='username relative to the CLI call', required=False)
     parser.add_argument('--yaml', help='Path to YAML input/output file for to the CLI call', required=False)
@@ -165,6 +185,8 @@ def main():
         return system_cli(args, subcommands)
     elif args.command == 'team':
         return team_cli(args, subcommands)
+    elif args.command == 'user':
+        return user_cli(args, subcommands)
     else:
         print('Command is not yet supported: {c}'.format(c=args.command))
     return 0
